@@ -60,9 +60,9 @@ public class USMVersion {
 	 * 0.9.0: Beta
 	 * 6.13: Current head for OX release 6.14
 	 */
-	public static final String VERSION = "6.22.0-5";
+	public static final String VERSION = "6.22.1-6";
 
-	public static final String BUILD_NUMBER = "4a3fb274c4e422f62a39ea825b610a9d6ca9ef13";
+	public static final String BUILD_NUMBER = "d61a3b3e12e74f21ddbbd4d1a820e37dcefbfb07- 6593";
 
 	public static final String VERSION_BUILD = VERSION + "-" + BUILD_NUMBER;
 }
