@@ -170,8 +170,8 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 
 	public DataObject[] getAllRecurrencesAsAppointments(Session session, BitSet requestedFields, DataObject seriesObject)
 			throws USMException {
-		return getAllRecurrencesAsAppointments(session, requestedFields, seriesObject, session.getStartDate(), session
-				.getEndDate());
+		return getAllRecurrencesAsAppointments(session, requestedFields, seriesObject, session.getStartDate(),
+				session.getEndDate());
 	}
 
 	public DataObject[] getAllRecurrencesAsAppointments(Session session, BitSet requestedFields,
@@ -276,8 +276,8 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 		Map<String, String> parameters = new HashMap<String, String>();
 		JSONObject requestBody = createRequestBodyWithIgnoreConflicts(object, false);
 		//		printTimeValues("New", requestBody);
-		JSONResult result = _ajaxAccess.doPut(CalendarConstants.CALENDAR_PATH, UtilConstants.ACTION_NEW, object
-				.getSession(), parameters, requestBody);
+		JSONResult result = _ajaxAccess.doPut(CalendarConstants.CALENDAR_PATH, UtilConstants.ACTION_NEW,
+				object.getSession(), parameters, requestBody);
 		checkResult(result, JSONResultType.JSONObject);
 		JSONObject o = result.getJSONObject();
 		readOptionalTimestamp(o, object);
@@ -414,10 +414,10 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 						//this is a special case for changing the until of the series. (iPhone - for all future appointments)
 						//All relevant recurrence fields have to be sent
 						requestBody.put(CommonCalendarTasksFieldNames.RECURRENCE_TYPE, recType);
-						requestBody.put(CommonCalendarTasksFieldNames.INTERVAL, object
-								.getFieldContent(CommonCalendarTasksFieldNames.INTERVAL));
-						requestBody.put(CommonCalendarTasksFieldNames.UNTIL, object
-								.getFieldContent(CommonCalendarTasksFieldNames.UNTIL));
+						requestBody.put(CommonCalendarTasksFieldNames.INTERVAL,
+								object.getFieldContent(CommonCalendarTasksFieldNames.INTERVAL));
+						requestBody.put(CommonCalendarTasksFieldNames.UNTIL,
+								object.getFieldContent(CommonCalendarTasksFieldNames.UNTIL));
 						Object days = object.getFieldContent(CommonCalendarTasksFieldNames.DAYS);
 						if (days instanceof Number && ((Number) days).intValue() != 127)
 							requestBody.put(CommonCalendarTasksFieldNames.DAYS, days);
@@ -468,6 +468,12 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 		parameters.put(UtilConstants.FOLDER, object.getOriginalParentFolderID());
 		parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
 		JSONObject requestBody = createRequestBodyWithIgnoreConflicts(object, true);
+		try {
+			requestBody.put("ignoreOutdatedSequence", "true");
+		} catch (JSONException e1) {
+			throw new USMException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER14,
+					"Error on creating request body", e1);
+		}
 
 		//		printTimeValues("Change", requestBody);
 		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_UPDATE, object.getSession(),
