@@ -48,16 +48,38 @@
  */
 package com.openexchange.usm.contenttypes.folder.impl;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.BitSet;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 
 import org.apache.commons.logging.Log;
-import org.json.*;
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
 
-import com.openexchange.usm.api.contenttypes.*;
-import com.openexchange.usm.api.exceptions.*;
-import com.openexchange.usm.api.session.*;
-import com.openexchange.usm.contenttypes.util.*;
-import com.openexchange.usm.ox_json.*;
+import com.openexchange.usm.api.contenttypes.ContentType;
+import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.FolderContentType;
+import com.openexchange.usm.api.contenttypes.FolderContentTypeTransferHandler;
+import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
+import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
+import com.openexchange.usm.api.exceptions.FolderNotFoundException;
+import com.openexchange.usm.api.exceptions.InternalUSMException;
+import com.openexchange.usm.api.exceptions.OXCommunicationException;
+import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.exceptions.USMIllegalArgumentException;
+import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.Folder;
+import com.openexchange.usm.api.session.Session;
+import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
+import com.openexchange.usm.contenttypes.util.OXErrorConstants;
+import com.openexchange.usm.contenttypes.util.USMContentTypesUtilErrorCodes;
+import com.openexchange.usm.contenttypes.util.UtilConstants;
+import com.openexchange.usm.ox_json.JSONResult;
+import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.ox_json.OXJSONAccess;
 
 /**
  *
@@ -86,7 +108,8 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 			_journal.debug(session + " Read all " + _contentType.getID() + " in folder " + folder.getID());
 		Map<String, String> parameters = createParametersWithAllowedModules(session, requestedFields);
 		parameters.put(UtilConstants.PARENT, folder.getID());
-		String errorOnDuplicateNamePersistentField = session.getPersistentField(UtilConstants.ERROR_ON_DUPLICATE_NAME_DB_FIELD);
+		String errorOnDuplicateNamePersistentField = session
+				.getPersistentField(UtilConstants.ERROR_ON_DUPLICATE_NAME_DB_FIELD);
 		if (errorOnDuplicateNamePersistentField != null && errorOnDuplicateNamePersistentField.length() > 0)
 			parameters.put(UtilConstants.ERROR_ON_DUPLICATE_NAME, errorOnDuplicateNamePersistentField);
 		DataObject[] listOfResults = performActionAndCheckRights(UtilConstants.ACTION_LIST, folder, requestedFields,
@@ -108,8 +131,8 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 		Map<String, String> parameters = createParametersWithAllowedModules(session, requestedFields);
 		parameters.put(UtilConstants.PARENT, folder.getID()); //object ID of the folder
 		parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
-		return tranformToFolders(getListOfUpdates(folder, requestedFields, _ajaxAccess.doGet(getOXAjaxAccessPath(),
-				UtilConstants.ACTION_UPDATES, session, parameters)));
+		return tranformToFolders(getListOfUpdates(folder, requestedFields,
+				_ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_UPDATES, session, parameters)));
 	}
 
 	@Override
@@ -137,6 +160,7 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 		JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_GET, session, parameters);
 		if (result.getResultType() == JSONResultType.Error) {
 			checkConflictingChange(result.getJSONObject());
+			checkAuthenticationFailed(result.getJSONObject());
 			throw new FolderNotFoundException(USMContentTypesFolderErrorCodes.FOLDER_NOT_FOUND, "Folder not found: "
 					+ object.getUUID() + '(' + object.getID() + ')');
 		}
@@ -144,7 +168,23 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 		updateDataObjectFromJSONResult(object, requestedFields, result);
 	}
 
-	private void addTreeParameter(Session session, Map<String,String> parameters) {
+	protected void checkAuthenticationFailed(JSONObject errorObject) throws InternalUSMException,
+			AuthenticationFailedException {
+		try {
+			int category = errorObject.optInt(UtilConstants.CATEGORY);
+			String message = errorObject.getString(UtilConstants.ERROR);
+			String code = errorObject.getString(UtilConstants.CODE);
+			if (category == OXErrorConstants.CATEGORY_PERMISSION && OXErrorConstants.MSG_1000.equals(code)) {
+				throw new AuthenticationFailedException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER15,
+						message, errorObject);
+			}
+		} catch (JSONException e) {
+			throw new InternalUSMException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER16,
+					"OX server sent an invalid  error object " + errorObject);
+		}
+	}
+
+	private void addTreeParameter(Session session, Map<String, String> parameters) {
 		String folderTree = session.getPersistentField(FolderContentType.FOLDER_TREE);
 		if (folderTree != null && folderTree.length() > 0)
 			parameters.put(UtilConstants.TREE, folderTree);
@@ -154,7 +194,7 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 		Session session = object.getSession();
 		if (_journal.isDebugEnabled())
 			_journal.debug(session + " Delete folder " + object.getID());
-		Map<String,String> parameters = new HashMap<String, String>();
+		Map<String, String> parameters = new HashMap<String, String>();
 		parameters.put(UtilConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
 		addTreeParameter(session, parameters);
 		JSONArray array = new JSONArray();
@@ -173,7 +213,7 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 		if (_journal.isDebugEnabled())
 			_journal.debug(session + " Create folder " + object.getID());
 		checkIDLength(object);
-		Map<String,String> parameters = new HashMap<String, String>();
+		Map<String, String> parameters = new HashMap<String, String>();
 		parameters.put(UtilConstants.PARENTFOLDER_ID, object.getParentFolderID());
 		addTreeParameter(session, parameters);
 		JSONObject requestBody = createRequestBody(object, false, true);
@@ -189,19 +229,19 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 		}
 		readOptionalTimestamp(o, object);
 	}
-	
+
 	private void checkIDLength(Folder object) throws USMException {
 		if (isFolderIDTooLong(object))
 			throw new USMException(USMContentTypesFolderErrorCodes.FOLDER_ID_TOO_LONG, "Folder id: " + object.getID()
 					+ " is too long");
 	}
-	
-	private boolean isFolderIDTooLong (DataObject object) {
+
+	private boolean isFolderIDTooLong(DataObject object) {
 		String id = object.getID();
-		if(id == null) return false;
+		if (id == null)
+			return false;
 		return id.length() > FOLDER_ID_LENGTH_LIMIT;
 	}
-	
 
 	public void writeUpdatedFolder(Folder object, long timestamp) throws USMException {
 		checkIDLength(object);
@@ -224,7 +264,7 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 
 	private Map<String, String> createCommonParameters(Session session, BitSet requestedFields)
 			throws UnsupportedContentOperationException {
-		Map<String,String> parameters = new HashMap<String, String>();
+		Map<String, String> parameters = new HashMap<String, String>();
 		addTreeParameter(session, parameters);
 		parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
 		return parameters;
