@@ -66,6 +66,7 @@ import org.json.JSONObject;
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.contenttypes.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.FolderConstants;
 import com.openexchange.usm.api.contenttypes.FolderContentType;
 import com.openexchange.usm.api.contenttypes.FolderContentTypeTransferHandler;
 import com.openexchange.usm.api.database.DatabaseAccessException;
@@ -252,7 +253,8 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
 				if (v instanceof Object[]) {
 					for (Object e : ((Object[]) v)) {
 						if (isChangeExceptionOutOfSyncRange(e)
-								|| !isCurrentUserParticipantToChangeException(exceptions, e))
+								|| (!isParentFolderShared(o) && !isCurrentUserParticipantToChangeException(exceptions,
+										e)))
 							deleteExceptions.put(e);
 						else
 							foundChange = true;
@@ -279,6 +281,22 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
 		return newObject;
 	}
 
+	private boolean isParentFolderShared(DataObject o) {
+		Folder parentFolder = o.getParentFolder();
+		if (parentFolder == null)
+			try {
+				parentFolder = _session.getCachedFolder(o.getParentFolderID());
+			} catch (DatabaseAccessException e) {
+				return false;
+			} catch (USMSQLException e) {
+				return false;
+			}
+		if (parentFolder == null)
+			return false;
+		else
+			return FolderType.SHARED.matches(parentFolder.getFieldContent(FolderConstants.TYPE));
+	}
+
 	private boolean isCurrentUserParticipantToChangeException(List<DataObject> exceptions, Object e) {
 		DataObject exceptionObject = findDataObjectByRecurrenceDatePosition(exceptions, e);
 		int currentUser = _session.getUserIdentifier();
