@@ -53,20 +53,17 @@ import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.UnsupportedEncodingException;
 import java.util.Map;
-
 import javax.servlet.ServletException;
 import javax.servlet.ServletOutputStream;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-
 import org.apache.commons.httpclient.HttpStatus;
 import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.osgi.service.http.HttpService;
 import org.osgi.service.http.NamespaceException;
-
 import com.openexchange.usm.api.contenttypes.ContentTypeManager;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMJSONException;
@@ -244,8 +241,9 @@ public class USMJSONServlet extends HttpServlet {
 	protected void doPut(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
 		long startTime = System.currentTimeMillis();
 		String command = getCommandName(request);
-		if (_journal.isDebugEnabled())
-			_journal.debug("HTTP PUT " + command);
+		if (_journal.isDebugEnabled()) {
+            _journal.debug("HTTP PUT " + command);
+        }
 		try {
 			ResponseObject result;
 			CommandHandler handler = null;
@@ -312,8 +310,9 @@ public class USMJSONServlet extends HttpServlet {
 				os.flush();
 				os.close();
 			}
-			if (_journal.isDebugEnabled())
-				_journal.debug(generateTimeLog(handler, command, System.currentTimeMillis() - startTime));
+			if (_journal.isDebugEnabled()) {
+                _journal.debug(generateTimeLog(handler, command, System.currentTimeMillis() - startTime));
+            }
 		} catch (Exception error) {
 			_journal.error("Open-Xchange USM/JSON: Internal server error in " + command, error);
 			response.sendError(HttpStatus.SC_INTERNAL_SERVER_ERROR);
@@ -326,24 +325,28 @@ public class USMJSONServlet extends HttpServlet {
 		sb.append(session).append(' ').append(command).append(' ').append(result.getStatusCode());
 		if (result.getStatusCode() != ResponseStatusCode.SUCCESS) {
 			sb.append(' ').append(result.getErrorCode());
-			if (result.getErrorMessage() != null)
-				sb.append(' ').append(result.getErrorMessage());
+			if (result.getErrorMessage() != null) {
+                sb.append(' ').append(result.getErrorMessage());
+            }
 		}
 		return sb.toString();
 	}
 
 	private String getCommandName(HttpServletRequest request) {
 		String[] result = request.getParameterValues(COMMAND);
-		if (result != null && result.length == 1)
-			return result[0];
+		if (result != null && result.length == 1) {
+            return result[0];
+        }
 		String command = request.getPathInfo();
 		// Remove all leading '/' in the sub-path (not just the first, in case the client is uses a wrong configuration)
 		int i = 0;
 		int length = command.length();
-		while (length > i && command.charAt(i) == '/')
-			i++;
-		if (i > 0)
-			command = command.substring(i);
+		while (length > i && command.charAt(i) == '/') {
+            i++;
+        }
+		if (i > 0) {
+            command = command.substring(i);
+        }
 		// XXX This is only a temporary workaround for a bug in the OX ServletContainer
 		//		int index = command.lastIndexOf('/');
 		//		if (index >= 0)
@@ -356,12 +359,14 @@ public class USMJSONServlet extends HttpServlet {
 		String contentType = request.getContentType();
 		if (contentType != null) {
 			int semiColon = contentType.indexOf(';');
-			if (semiColon >= 0)
-				contentType = contentType.substring(0, semiColon);
+			if (semiColon >= 0) {
+                contentType = contentType.substring(0, semiColon);
+            }
 		}
-		if (!ServletConstants.TEXT_JAVASCRIPT.equals(contentType))
-			throw new USMJSONAPIException(ConnectorBundleErrorCodes.BAD_REQUEST, ResponseStatusCode.BAD_REQUEST,
+		if (!ServletConstants.TEXT_JAVASCRIPT.equals(contentType)) {
+            throw new USMJSONAPIException(ConnectorBundleErrorCodes.BAD_REQUEST, ResponseStatusCode.BAD_REQUEST,
 					"Request type not \"text/javascript\"");
+        }
 		//read the JSON object from the request
 		BufferedReader reader = null;
 		try {
@@ -369,8 +374,9 @@ public class USMJSONServlet extends HttpServlet {
 					new InputStreamReader(request.getInputStream(), ServletConstants.UTF_ENCODING_8));
 			char[] buffer = new char[4096];
 			StringBuilder sb = new StringBuilder(4096);
-			for (int count = reader.read(buffer); count >= 0; count = reader.read(buffer))
-				sb.append(buffer, 0, count);
+			for (int count = reader.read(buffer); count > 0; count = reader.read(buffer)) {
+                sb.append(buffer, 0, count);
+            }
 			JSONObject requestObject = new JSONObject(sb.toString());
 			return requestObject;
 		} catch (UnsupportedEncodingException e) {
@@ -413,14 +419,16 @@ public class USMJSONServlet extends HttpServlet {
 
 	public long getPingInterval() {
 		int nextIndex = (_pingTimestampsIndex + 1 >= _pingTimestamps.length) ? 0 : _pingTimestampsIndex + 1;
-		if (_pingTimestamps[nextIndex] == 0)
-			return _minPingInterval;
+		if (_pingTimestamps[nextIndex] == 0) {
+            return _minPingInterval;
+        }
 		long deltaT = _pingTimestamps[_pingTimestampsIndex] - _pingTimestamps[nextIndex];
-		if (deltaT < 1)
-			deltaT = 1;
-		if (deltaT >= ONE_SECOND * _pingSampleSize)
-			return _minPingInterval;
-		else {
+		if (deltaT < 1) {
+            deltaT = 1;
+        }
+		if (deltaT >= ONE_SECOND * _pingSampleSize) {
+            return _minPingInterval;
+        } else {
 			long newInterval = _minPingInterval * ONE_SECOND / deltaT;
 			return (newInterval > _maxPingInterval) ? _maxPingInterval : newInterval;
 		}
@@ -428,19 +436,22 @@ public class USMJSONServlet extends HttpServlet {
 
 	public void newPingRequestArrived() {
 		_pingTimestampsIndex++;
-		if (_pingTimestampsIndex >= _pingTimestamps.length)
-			_pingTimestampsIndex = 0;
+		if (_pingTimestampsIndex >= _pingTimestamps.length) {
+            _pingTimestampsIndex = 0;
+        }
 		_pingTimestamps[_pingTimestampsIndex] = System.currentTimeMillis();
 	}
 
 	private String generateTimeLog(CommandHandler handler, String command, long duration) {
 		Session session = (handler == null) ? null : handler.getSession();
-		if (session == null)
-			return "No session: " + command + " executed in " + duration + " ms.";
+		if (session == null) {
+            return "No session: " + command + " executed in " + duration + " ms.";
+        }
 		Object numberOfCalls = session.getCustomProperty(OXJSONPropertyNames.NUMBER_OF_CALLS);
 		Object accumulatedTime = session.getCustomProperty(OXJSONPropertyNames.ACCUMULATED_TIME);
-		if (numberOfCalls == null || accumulatedTime == null)
-			return session + ": " + command + " executed in " + duration + " ms, no OX calls made.";
+		if (numberOfCalls == null || accumulatedTime == null) {
+            return session + ": " + command + " executed in " + duration + " ms, no OX calls made.";
+        }
 		return session + ": " + command + " executed in " + duration + " ms, " + numberOfCalls + " OX calls took "
 				+ accumulatedTime + " ms.";
 	}
