@@ -58,9 +58,9 @@ public class USMJSONVersion {
 	/**
 	 * USM JSON versions
 	 */
-	public static final String VERSION = "6.22.0-5";
+	public static final String VERSION = "6.22.1-6";
 
-	public static final String BUILD_NUMBER = "4a3fb274c4e422f62a39ea825b610a9d6ca9ef13";
+	public static final String BUILD_NUMBER = "d61a3b3e12e74f21ddbbd4d1a820e37dcefbfb07- 6593";
 
 	/**
 	 * API version number used to determine compatibility between client and server
