@@ -48,17 +48,23 @@
  */
 package com.openexchange.usm.session.impl;
 
+import java.sql.PreparedStatement;
+import java.sql.ResultSet;
+import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.UUID;
+
 import javax.management.MalformedObjectNameException;
 import javax.management.NotCompliantMBeanException;
 import javax.management.ObjectName;
+
 import org.apache.commons.logging.Log;
 import org.json.JSONObject;
+
 import com.openexchange.exception.OXException;
 import com.openexchange.management.ManagementService;
 import com.openexchange.timer.ScheduledTimerTask;
@@ -70,6 +76,7 @@ import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
 import com.openexchange.usm.api.contenttypes.FolderContentType;
 import com.openexchange.usm.api.database.DatabaseAccess;
 import com.openexchange.usm.api.database.DatabaseAccessException;
+import com.openexchange.usm.api.database.EncapsulatedConnection;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMAccessDeniedException;
@@ -94,6 +101,7 @@ import com.openexchange.usm.session.sync.IncrementalContentSyncer;
 import com.openexchange.usm.session.sync.OXDataCache;
 import com.openexchange.usm.session.sync.SlowContentSyncer;
 import com.openexchange.usm.util.JSONToolkit;
+import com.openexchange.usm.util.Toolkit;
 import com.openexchange.usm.uuid.OXObjectID;
 import com.openexchange.usm.uuid.UUIDMappingService;
 import com.openexchange.usm.uuid.exceptions.OXObjectAlreadyMappedException;
@@ -311,6 +319,40 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 		return getSession(user, password, protocol, device, null, "127.0.0.1", new HashMap<String, String>());
 	}
 
+	public boolean exitsSessionInDB(String user, String protocol, String device) throws USMException {
+		SessionID id = new SessionID(user, protocol, device);
+		SessionImpl session = _sessionStorage.getSession(id);
+		if (session != null)
+			return session.checkProperDBStorage();
+		else {
+			List<Integer> contextIds = _databaseAccess.getAllContextIds();
+			for (Integer contextId : contextIds) {
+				EncapsulatedConnection con = _databaseAccess.getReadOnly(contextId);
+				PreparedStatement statement = null;
+				boolean sessionFound = false;
+				try {
+					statement = con.prepareStatement("select usmSessionId from USMSession where "
+							+ PersistentSessionDataSQLStatements.DEVICE_IN_CONTEXT);
+					statement.setInt(1, contextId);
+					statement.setString(2, device);
+					statement.setString(3, protocol);
+					ResultSet result = statement.executeQuery();
+					sessionFound = result.next();
+				} catch (SQLException e) {
+					String errorMessage = " SQL error while retrieving session from DB";
+					throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_DB_ERROR_2,
+							errorMessage, e);
+				} finally {
+					Toolkit.close(statement);
+					Toolkit.close(con);
+				}
+				if (sessionFound)
+					return true;
+			}
+			return false;
+		}
+	}
+
 	public Session getSession(String user, String password, String protocol, String device,
 			SessionInitializer initializer, String clientIP, Map<String, String> xHeaders) throws USMException {
 		SessionID id = new SessionID(user, protocol, device);
